# This module is deprecated as of 2012-09-07.
# It is no longer being imported or used.

from tendenci.apps.pluginmanager.settings import plugin_apps
from tendenci.apps.pluginmanager.urls import get_url_patterns
