DURATION_CHOICES = (
    (14,'14 Days from Activation date'), 
    (30,'30 Days from Activation date'), 
    (60,'60 Days from Activation date'), 
    (90,'90 Days from Activation date'),
    (120,'120 Days from Activation date'),
    (365,'1 Year from Activation date'),
)
ADMIN_DURATION_CHOICES = (
    (0, 'Unlimited'),
    (14,'14 Days from Activation date'), 
    (30,'30 Days from Activation date'), 
    (60,'60 Days from Activation date'), 
    (90,'90 Days from Activation date'),
    (120,'120 Days from Activation date'),
    (365,'1 Year from Activation date'),
)

STATUS_CHOICES = (
    (1, 'Active'),
    (0, 'Inactive'),
)
