from tendenci.core.perms.managers import TendenciBaseManager

class PhotoSetManager(TendenciBaseManager):
    """
    Model Manager
    """
    pass

class PhotoManager(TendenciBaseManager):
    """
    Model Manager
    """
    pass
    
